
//`#start header` -- edit after this line, do not edit this line
// =============================================================
//
// Count4Bit_v1_000.v
// 
// Parameter: 
// uint8 period - 4-bit period value
//
// Inputs:
// en		- Hardware enable. If low, outputs are still active 
// 			  but the component does not change states.
// reset	- Active high, synchronous reset
// clock	- Operating frequency of component
//
// Outputs:
// tc	 	- Synchronous terminal count. Goes high for 1 clock 
//			  cycle when count value equals period value.
// count 	- 4-bit current count value 
//
// The 4-bit counter is a hardware-only, 4-bit up counter.  
//
// =============================================================
`include "cypress.v"
//`#end` -- edit above this line, do not edit this line

// Generated on 08/30/2012 at 15:28
// Component: Count4Bit_v1_000
module Count4Bit_v1_00 (
	output reg [3:0] count,
	output reg tc,
	input   clock,
	input   en,
	input   reset
);
	/* Note that the value assigned to the parameter in this line
	 * has no effect. The actual parameter value is taken from 
	 * the component customizer.
	 */
	parameter period = 15;

//`#start body` -- edit after this line, do not edit this line

	always @ (posedge clock)
	begin
		if(reset)					/* Initialize the counter */
		begin
			count <= 4'b0;
			tc <= 1'b0;
		end
		else 						/* counter is not in reset */
		begin
			if(en)					/* start counting */
			begin
				if(count == period) /* reached terminal count */
				begin
					tc <= 1'b1;
					count <= 4'b0;
				end
				else 				/* count is less than the period, so count up */
				begin
					count <= count + 1;
					tc <= 1'b0;
				end
			end
			else 					/* enable is 0 - so preserve the output states */
			begin
				count <= count;
				tc <= tc;
			end
		end
	end

//`#end` -- edit above this line, do not edit this line
endmodule
//`#start footer` -- edit after this line, do not edit this line
//`#end` -- edit above this line, do not edit this line
